==> rc-ui-lib-2.0.4.tgz: package/lib/lazyload/Lazyload.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_utils = require("./utils");
var import_LazyloadEvent = __toESM(require("./LazyloadEvent"));
var import_LazyloadObserve = __toESM(require("./LazyloadObserve"));
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
const Lazyload = (props) => {
  const [mode, setMode] = (0, import_react.useState)("observer");
  const _a = props, {
    observer,
    eventOptions
  } = _a, resetProps = __objRest(_a, [
    "observer",
    "eventOptions"
  ]);
  (0, import_react.useEffect)(() => {
    const toSetMode = (value) => {
      if (!import_utils.hasIntersectionObserver && value === import_utils.modeType.observer) {
        value = import_utils.modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? import_utils.modeType.observer : import_utils.modeType.event);
  }, [observer]);
  return /* @__PURE__ */ import_react.default.createElement(import_react.default.Fragment, null, mode === import_utils.modeType.event ? /* @__PURE__ */ import_react.default.createElement(import_LazyloadEvent.default, _extends({}, resetProps, eventOptions)) : /* @__PURE__ */ import_react.default.createElement(import_LazyloadObserve.default, resetProps));
};
Lazyload.defaultProps = {
  loading: null,
  height: 0,
  observer: true
};
var stdin_default = Lazyload;

==> rc-ui-lib-2.1.1.tgz: package/lib/lazyload/Lazyload.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_utils = require("./utils");
var import_LazyloadEvent = __toESM(require("./LazyloadEvent"));
var import_LazyloadObserve = __toESM(require("./LazyloadObserve"));
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
const Lazyload = (props) => {
  const [mode, setMode] = (0, import_react.useState)();
  const _a = props, {
    observer,
    eventOptions
  } = _a, resetProps = __objRest(_a, [
    "observer",
    "eventOptions"
  ]);
  (0, import_react.useEffect)(() => {
    const toSetMode = (value) => {
      if (!import_utils.hasIntersectionObserver && value === import_utils.modeType.observer) {
        value = import_utils.modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? import_utils.modeType.observer : import_utils.modeType.event);
  }, [observer]);
  return /* @__PURE__ */ import_react.default.createElement(import_react.default.Fragment, null, mode === import_utils.modeType.event ? /* @__PURE__ */ import_react.default.createElement(import_LazyloadEvent.default, _extends({}, resetProps, eventOptions)) : mode === import_utils.modeType.observer ? /* @__PURE__ */ import_react.default.createElement(import_LazyloadObserve.default, resetProps) : null);
};
Lazyload.defaultProps = {
  loading: null,
  height: 0,
  observer: true
};
var stdin_default = Lazyload;
